@@ -7,7 +7,7 @@ from .base.move import MoveSet
 from .base.piece import Piece, PieceType
 from .game.janggi_game import JanggiGame
 from .game.game_log import GameLog
-from .game.game_window import GameWindow
-from .game.replay_viewer import ReplayViewer
+from .ui.game_window import GameWindow
+from .ui.replay_viewer import ReplayViewer
 from .proto import log_pb2
-from .utils import replay
\ No newline at end of file
+from .utils import generate_random_game, play, replay
\ No newline at end of file
