@@ -11,7 +11,7 @@ from janggi import GameWindow
 from janggi import ReplayViewer
 
 logging.basicConfig()
-logging.root.setLevel(logging.INFO)
+logging.root.setLevel(logging.DEBUG)
 
 if __name__ == '__main__':
     camp = Camp(random.choice([-1, 1]))
@@ -22,8 +22,9 @@ if __name__ == '__main__':
     print(game.board)
 
     # Test replay viewer
-    moves = [(Location(3,0), Location(3,1)), (Location(6,8), Location(6,7)), (Location(0,0), Location(4,0))]
+    moves = [(Location(3, 0), Location(3, 1)), (Location(6, 8),
+                                                Location(6, 7)), (Location(0, 0), Location(4, 0))]
     game_log = GameLog(cho_formation, han_formation, camp, moves)
     game_log.generate_board_log()
     replay_viewer = ReplayViewer(game_log)
-    replay_viewer.run()
\ No newline at end of file
+    replay_viewer.run()
